import 'package:cpt_community/router/page/community_page_router.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_text_view.dart';

import '../../../components/newfeed_card_header.dart';
import '../../../components/newsfeed_card_content.dart';
import '../../../components/newsfeed_card_footer.dart';
import 'newsfeed_detail_state.dart';
import 'newsfeed_detail_vm.dart';

@RoutePage()
class NewsfeedDetailPage extends HookConsumerWidget {
  final int? id;
  final String? type;  // news  following foryou

  const NewsfeedDetailPage({Key? key, required this.id, required this.type}) : super(key: key);
  // 启动当前页面
  static void startInstance({BuildContext? context, int? id, String? type='news'}) {
    if (context != null) {
      context.router.push(NewsfeedDetailPageRoute(id: id, type: type));
    } else {
      appRouter.push(NewsfeedDetailPageRoute(id: id, type: type));
    }
  }


  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final vm = ref.read(newsfeedDetailVmProvider.notifier);
    final state = ref.watch(newsfeedDetailVmProvider);
    useEffect((){
      // 组件挂载时执行 - 执行接口请求
      // Future.microtask(() => vm.fetchList());
      return () {
        // 组件卸载时执行
      };
    }, []);


    return Scaffold(
      appBar: MyAppBar.appBar(
        context,
        "News Feed Detail",
        backgroundColor: context.appColors.whiteBG,
      ),
      backgroundColor: ColorUtils.string2Color("#F2F3F6"),
      body: Column(
        children: [
          _buildTopCard(context, ref),
         // 评论区域
          Expanded(child: _buildCommentListCard(context, ref)),
         //  底部 like comments 按钮区
          Container(
            color: ColorUtils.string2Color("#2956B7"),
            child: Row(
              children: [
                Expanded(
                  child: MyButton(
                    minHeight: 50,
                    text: 'Like',
                    textColor: Colors.white,
                    onPressed: () {},
                  )
                )
              ]
            )
          )
        ],
      ),
    );
  }

  Widget _buildTopCard(BuildContext context, WidgetRef ref){
    final vm = ref.read(newsfeedDetailVmProvider.notifier);
    final state = ref.watch(newsfeedDetailVmProvider);
    return Container(
      width: double.infinity,
      //   color: Colors.yellow,
      child: Stack(
        children: [
          Container(
            margin: const EdgeInsets.only(left: 15, right: 15,top: 14,bottom: 14),
            color: Colors.white,
            padding: const EdgeInsets.only(left: 15, right: 15,top: 17,bottom: 17),
            height: 280,
            child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  // 卡片头部(头像 标题 时间)
                  NewsFeedCardHeader(
                    key: UniqueKey(),
                    title: state?.detailInfo!['title'],
                    avator: state?.detailInfo['avator'],
                    time: state?.detailInfo['time'],
                  ),
                  const SizedBox(height: 15),
                  // 卡片中间 （文字和图片）
                  Expanded(
                    child: NewsFeedCardContent(
                      key: UniqueKey(),
                      content: state.detailInfo['content'],
                      imageUrls: state.detailInfo['imageUrls'],
                    ),
                  ),
                  const SizedBox(height: 26),
                ]
            ),
          ),
          // 右上角 关注/取消关注 按钮
          Visibility(
            visible: !state.detailInfo['isFollow'],
            child: Positioned(
                right: 40,
                top: 35,
                child: Container(
                  width: 83.5,
                  height: 45.5,
                  alignment: Alignment.center,
                  // decoration: BoxDecoration(
                  //   color:  ColorUtils.string2Color('#4161D0'),
                  //   borderRadius: BorderRadius.circular(5),
                  // ),
                  child: MyButton(
                    text: '+Follow',
                    textColor: Colors.white,
                    backgroundColor: ColorUtils.string2Color('#4161D0'),
                    radius: 8,
                    minHeight: 27.5,
                    padding: const EdgeInsets.only(left: 5, right: 5,top:9,bottom:9),
                    fontWeight: FontWeight.w400,
                    fontSize: 14,
                    onPressed: (){
                      // Navigator.pop(context);
                    },
                  ),
                )
            ),
          )
        ],
      ),
    );
  }

  Widget _buildCommentListCard(BuildContext context,  WidgetRef ref){
    return Container(
      color: Colors.white,
      margin: const EdgeInsets.only(left: 15, right: 15,top: 18,bottom: 18),
      child: Column(
        children: [
          Row(
            children: [
              Expanded(
                child: Container(
                  padding: const EdgeInsets.only(left: 15, right: 15,top: 14,bottom: 14),
                  child: Row(
                    children: [
                      MyTextView('Comments', textColor: ColorUtils.string2Color("#2956B7"), fontSize: 15, isFontLight: true,),
                      const SizedBox(width: 5,),
                      MyTextView('95', textColor: ColorUtils.string2Color("#2956B7"), fontSize: 15, isFontLight: true,),
                    ]
                  )
                )
              )
            ],
          ),
          const Expanded(
            child:  Row(
              children: [
                 Text("fsdf"),
              ],
            ),
          ),
        ]
      ),
    ).borderRadius(all:8);
  }
}
