import 'package:cpt_community/components/garage_card_content.dart';
import 'package:cpt_community/components/garage_card_footer.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/my_appbar.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:widgets/widget_export.dart';

import '../../../components/garage_card_header.dart';
import '../../../components/newfeed_card_header.dart';
import '../../../router/page/community_page_router.dart';
import 'for_sale_vm.dart';

@RoutePage()
class ForsalePage extends HookConsumerWidget {
  const ForsalePage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const ForsalePageRoute());
    } else {
      appRouter.push(const ForsalePageRoute());
    }
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final vm = ref.read(forsaleVmProvider.notifier);
    return Scaffold(
      // appBar: MyAppBar.appBar(
      //   context,
      //   "Forsale",
      //   backgroundColor: context.appColors.whiteBG,
      // ),
      // backgroundColor: ColorUtils.string2Color("#F2F3F6"),
      body: Column(
        children: [
            Expanded(
              child: EasyRefresh(
                // 上拉加载
                onLoad: () async{
                  Log.d("----onLoad");
                  vm.onLoadData();
                },
                // 下拉刷新
                onRefresh: () async{
                  Log.d("----onRefresh");
                  vm.refreshListData();
                },
                child: _buildForsaleFeedList(context, ref, vm),
              ),
            )
        ],
      )
    );
  }

  Widget _buildForsaleItem(BuildContext context, WidgetRef ref, item, vm){
    return Container(
      width: double.infinity,
      //   color: Colors.yellow,
      child: Stack(
        children: [
          Container(
            margin: const EdgeInsets.only(left: 15, right: 15,top: 14,bottom: 14),
            color: Colors.white,
            padding: const EdgeInsets.only(left: 15, right: 15,top: 17,bottom: 17),
            height: 280,
            child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  // 卡片头部(头像 标题 时间)
                  GarageCardHeader(
                    key: UniqueKey(),
                    itemObj: item,
                  ),
                  const SizedBox(height: 15),
                  // 卡片中间 （文字和图片）
                  // Expanded(
                  //   child: GarageCardContent(
                  //     key: UniqueKey(),
                  //     content: item['content'],
                  //     imageUrls: item['imageUrls'],
                  //   ),
                  // ),
                  const SizedBox(height: 26),
                  // // 卡片底部 (点赞 评论 分享)
                  // GarageCardFooter(
                  //     key: UniqueKey(),
                  //     isLike: item['isLike'],
                  //     onLike: (){
                  //       vm.handlerClickActionBtn('like', item);
                  //     },
                  //     onComment: (){
                  //       vm.handlerClickActionBtn('comments', item);
                  //     },
                  //     onShare: (){
                  //       vm.handlerClickActionBtn('share', item);
                  //     },
                  // ),
                ]
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildForsaleFeedList(BuildContext context, WidgetRef ref, vm){
    final itemList = vm.state.list?? [];
    if(itemList.isEmpty){
      return const Center(child: Text('No Data'));
    }else {
      List itemsList = vm.state.list.toList();
      return ListView.builder(
        key: UniqueKey(),
        itemCount: itemsList.length,
        itemBuilder: (context, index) {
          return _buildForsaleItem(context, ref, itemsList[index], vm);
        },
      );
    }
    // return Text("879424");
  }
}