import 'package:plugin_platform/http/http_result.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import '../page/property_news_state.dart';
import '../repository/property_news_repository.dart';
part 'property_news_vm.g.dart';

@riverpod
class PropertyNewsVm extends _$PropertyNewsVm {
  late PropertyNewsRepository propertyNewsRepository;
  PropertyNewsState initState() {
    return PropertyNewsState(
      curPage: 1,
      pageSize: 10,
      list: [
        {
          "id": 1,
          "title": "fkladsfk fldask fldsakfllfkaslsd",
          "description": "fsklfdsk罚款乱收费上课了发送卡",
          "time": "2024-02-15 12:00:00",
          "isCollection": true,
          "pic": ""
        },
        {
          "id": 2,
          "title": "JHKFDSAJKjfkdsfjkasjkjklfajfkajifwoqirujweiqofjndsaikfniasdhfiasdhfiadshfifjadslfjkdlsafjlkadsj",
          "description": "oifosjf fjdskafj hjiwehfriohjfiash",
          "time": "2024-10-16 12:00:00",
          "isCollection": false,
          "pic": ""
        },
      ],
      filterCount: 2,
    );
  }

  @override
  PropertyNewsState build() {
    // 引入数据仓库
    propertyNewsRepository = ref.read(propertyNewsRepositoryProvider);
    // 初始化状态
    PropertyNewsState state = initState();
    // 初始化列表数据
    return state;
  }

  // 初始化页面数据
  initPageData() {
    Log.d("----property_news_vm-----initPageData");
    refreshListData();
  }

  // 上拉加载
  Future onLoadData() async {
    Log.d("----property_news_vm-----initListData");
    // await Future.delayed(const Duration(seconds: 2));
    // if(state.list.length >= state.filterCount){
    //   return;
    // }else {
    //   int curPage = state.curPage + 1;
    //   state = state.copyWith(curPage: curPage,);
    //   getListData();
    // }
    getListData();
  }

  // 获取list 列表数据
  void getListData<T>() async {
    Log.d("加载listData数据---------------start-----");
    try {
      //请求网络
      Map<String, dynamic>  params = {
        "curPage": state.curPage,
        "pageSize": state.pageSize,
      };
      Log.d("请求参数------$params");
      final result = await propertyNewsRepository.fetchPropertyNewsList(params);
      Log.d("请求完成结果------${result.data}");
      //校验成功失败
      if (result.isSuccess) {
        // state = state.copyWith(serverTime: result.data);
        state = state;
        ToastEngine.show("获取数据成功");
      } else {
        ToastEngine.show(result.errorMsg ?? "Network Load Error");
      }
    } catch (e) {
      ToastEngine.show("Error: $e");
    }
  }


  // 下拉刷新
  Future refreshListData() async {
    Log.d("----property_news_vm-----refreshListData ");

    // await Future.delayed(const Duration(seconds: 2));

    state = state.copyWith(curPage: 1, pageSize: 10);
    // ref.invalidateSelf();
    // ref.invalidate(propertyNewsVmProvider);
    getListData();

  }

  // 去新闻详情页
  void goNewsDetail(String item) {
    Log.d("goNewsDetail");
    // PropertyPage.startInstance(context: context, item: item);
  }

  // 收藏/取消收藏
  void handlerCollection(curItem, bool isCollection){

    List<Map<String, dynamic>> newList = state.list.map((item) {
        if(item['id'] == curItem['id']){
          return {
            ...item,
            'isCollection': !isCollection
          };
        }
        return item;
    }).toList();
    // Log.d("handlerCollection $newList");
    state = state.copyWith(list: newList);
    if(isCollection){
      ToastEngine.show("取消收藏");
    }else {
      ToastEngine.show("收藏成功");
    }
  }
}
