import 'package:plugin_platform/http/http_result.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import '../page/property_sale_state.dart';
import '../repository/property_sale_repository.dart';
part 'property_sale_vm.g.dart';

@riverpod
class PropertySaleVm extends _$PropertySaleVm {
  late PropertySaleRepository propertySaleRepository;
  PropertySaleState initState() {
    return PropertySaleState(
      curPage: 1,
      pageSize: 10,
      list: [
        {
          "id": 1,
          "title": "18 Sep 2024 BIK 39#09-XX 1337 psd 1001 sqft",
          "price": "\$1.338 M",
        },
        {
          "id": 2,
          "title": "18 Sep 2024 BIK 39#09-XX 1337 psd 1001 sqft",
          "price": "\$1.338 M",
        },
      ],
      filterCount: 2,
    );
  }

  @override
  PropertySaleState build() {
    // 引入数据仓库
    propertySaleRepository = ref.read(propertySaleRepositoryProvider);
    // 初始化状态
    PropertySaleState state = initState();
    // 初始化列表数据
    return state;
  }

  // 初始化页面数据
  initPageData() {
    Log.d("----property_news_vm-----initPageData");
    refreshListData();
  }

  // 上拉加载
  Future onLoadData() async {
    Log.d("----property_news_vm-----initListData");
    // await Future.delayed(const Duration(seconds: 2));
    // if(state.list.length >= state.filterCount){
    //   return;
    // }else {
    //   int curPage = state.curPage + 1;
    //   state = state.copyWith(curPage: curPage,);
    //   getListData();
    // }
    getListData();
  }

  // 获取list 列表数据
  void getListData<T>() async {
    Log.d("加载listData数据---------------start-----");
    try {
      //请求网络
      Map<String, dynamic>  params = {
        "curPage": state.curPage,
        "pageSize": state.pageSize,
      };
      Log.d("请求参数------$params");
      final result = await propertySaleRepository.fetchPropertyNewsList(params);
      Log.d("请求完成结果------${result.data}");
      //校验成功失败
      if (result.isSuccess) {
        // state = state.copyWith(serverTime: result.data);
        state = state;
        ToastEngine.show("获取数据成功");
      } else {
        ToastEngine.show(result.errorMsg ?? "Network Load Error");
      }
    } catch (e) {
      ToastEngine.show("Error: $e");
    }
  }


  // 下拉刷新
  Future refreshListData() async {
    Log.d("----property_news_vm-----refreshListData ");

    // await Future.delayed(const Duration(seconds: 2));

    state = state.copyWith(curPage: 1, pageSize: 10);
    // ref.invalidateSelf();
    // ref.invalidate(propertyNewsVmProvider);
    getListData();

  }

}
